<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'legit_news_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','legit-news-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Slider section enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_slider_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_slider_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
	'active_callback' 	=> 'legit_news_pro_is_slider_section_enable',
) ) );

// Slider post count number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_slider_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_slider_section',
	'active_callback'   => 'legit_news_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_slider_section_enable',
	'choices'			=> array( 
		'category' 	=> esc_html__( 'Category', 'legit-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_slider_section',
		'choices'			=> legit_news_pro_page_choices(),
		'active_callback'	=> 'legit_news_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_slider_section',
		'choices'			=> legit_news_pro_post_choices(),
		'active_callback'	=> 'legit_news_pro_is_slider_section_content_post_enable',
	) ) );


endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'legit_news_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'legit_news_pro_is_slider_section_content_category_enable'
) ) );


// Slider btn label setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[slider_btn_title]', array(
	'label'           	=> esc_html__( 'Slider Button Title', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_slider_section',
	'active_callback' 	=> 'legit_news_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

