<?php
/**
 * Photography Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Photography section
$wp_customize->add_section( 'legit_news_pro_photography_section', array(
	'title'             => esc_html__( 'Photography','legit-news-pro' ),
	'description'       => esc_html__( 'Photography Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Photography content enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_section_enable]', array(
	'default'			=> 	$options['photography_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[photography_section_enable]', array(
	'label'             => esc_html__( 'Photography Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_photography_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );

// photography title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['photography_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[photography_title]', array(
	'label'           	=> esc_html__( 'Title', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_photography_section',
	'active_callback' 	=> 'legit_news_pro_is_photography_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[photography_title]', array(
		'selector'            => '#reading div.section-header h2',
		'settings'            => 'legit_news_pro_theme_options[photography_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_photography_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_count]', array(
	'default'          	=> $options['photography_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_photography_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[photography_count]', array(
	'label'             => esc_html__( 'Number of page/post', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_photography_section',
	'active_callback'   => 'legit_news_pro_is_photography_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Hero content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_content_type]', array(
	'default'          	=> $options['photography_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[photography_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_photography_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_photography_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'legit-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['photography_count']; $i++ ) :
	// photography pages drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_content_page_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[photography_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_photography_section',
		'choices'			=> legit_news_pro_page_choices(),
		'active_callback'	=> 'legit_news_pro_is_photography_section_content_page_enable',
	) ) );

	// photography posts drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[photography_content_post_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[photography_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_photography_section',
		'choices'			=> legit_news_pro_post_choices(),
		'active_callback'	=> 'legit_news_pro_is_photography_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[photography_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'legit_news_pro_theme_options[photography_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_photography_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'legit_news_pro_is_photography_section_content_category_enable'
) ) );
