<?php
/**
 * Related Post Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Related Post section
$wp_customize->add_section( 'legit_news_pro_related_post_section', array(
	'title'             => esc_html__( 'Related Post','legit-news-pro' ),
	'description'       => esc_html__( 'Related Post Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Related Post content enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_section_enable]', array(
	'default'			=> 	$options['related_post_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[related_post_section_enable]', array(
	'label'             => esc_html__( 'Related Post Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );

// related_post title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['related_post_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[related_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_related_post_section',
	'active_callback' 	=> 'legit_news_pro_is_related_post_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[related_post_title]', array(
		'selector'            => '#related-posts div.section-header h2.section-title',
		'settings'            => 'legit_news_pro_theme_options[related_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_related_post_title_partial',
    ) );
}


// Hero content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_column]', array(
	'default'          	=> $options['related_post_column'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[related_post_column]', array(
	'label'             => esc_html__( 'Column Layout', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_related_post_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( 'Column 3', 'legit-news-pro' ),
		'col-4' 		=> esc_html__( 'Column 4', 'legit-news-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_count]', array(
	'default'          	=> $options['related_post_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_related_post_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[related_post_count]', array(
	'label'             => esc_html__( 'Number of page/post', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'active_callback'   => 'legit_news_pro_is_related_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Hero content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_content_type]', array(
	'default'          	=> $options['related_post_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[related_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_related_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'legit-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['related_post_count']; $i++ ) :
	// related_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[related_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_related_post_section',
		'choices'			=> legit_news_pro_page_choices(),
		'active_callback'	=> 'legit_news_pro_is_related_post_section_content_page_enable',
	) ) );

	// related_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[related_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_related_post_section',
		'choices'			=> legit_news_pro_post_choices(),
		'active_callback'	=> 'legit_news_pro_is_related_post_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[related_post_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'legit_news_pro_theme_options[related_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'legit_news_pro_is_related_post_section_content_category_enable'
) ) );

// related_post btn title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[related_post_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['related_post_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[related_post_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_related_post_section',
	'active_callback' 	=> 'legit_news_pro_is_related_post_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[related_post_btn_title]', array(
		'selector'            => '#related-posts div.view-all a.more-link',
		'settings'            => 'legit_news_pro_theme_options[related_post_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_related_post_btn_title_partial',
    ) );
}


// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[related_post_category_exclude]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Category_Control( $wp_customize,'legit_news_pro_theme_options[related_post_category_exclude]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_related_post_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'legit_news_pro_is_related_post_section_content_recent_enable'
) ) );
