<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function legit_news_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'legit-news-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function legit_news_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'legit-news-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function legit_news_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'legit-news-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'legit_news_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function legit_news_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'legit-news-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'legit-news-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'legit-news-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'legit-news-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'legit-news-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'legit-news-pro' ),
            'header-font-6'   => esc_html__( 'PLayfair Display', 'legit-news-pro' ),
        );

        $output = apply_filters( 'legit_news_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'legit_news_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function legit_news_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'legit-news-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'legit-news-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'legit-news-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'legit-news-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'legit-news-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'legit-news-pro' ),
        );

        $output = apply_filters( 'legit_news_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'legit_news_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function legit_news_pro_site_layout() {
        $legit_news_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'legit_news_pro_site_layout', $legit_news_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'legit_news_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function legit_news_pro_selected_sidebar() {
        $legit_news_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'legit-news-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'legit-news-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'legit-news-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'legit-news-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'legit-news-pro' ),
        );

        $output = apply_filters( 'legit_news_pro_selected_sidebar', $legit_news_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'legit_news_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function legit_news_pro_global_sidebar_position() {
        $legit_news_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'legit_news_pro_global_sidebar_position', $legit_news_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'legit_news_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function legit_news_pro_sidebar_position() {
        $legit_news_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'legit_news_pro_sidebar_position', $legit_news_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'legit_news_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function legit_news_pro_pagination_options() {
        $legit_news_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'legit-news-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'legit-news-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'legit-news-pro' ),
        );

        $output = apply_filters( 'legit_news_pro_pagination_options', $legit_news_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function legit_news_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'legit-news-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'legit-news-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'legit-news-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'legit-news-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'legit-news-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'legit-news-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'legit-news-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'legit-news-pro' ),
        );
        return apply_filters( 'legit_news_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'legit_news_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function legit_news_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'legit-news-pro' ),
            'off'       => esc_html__( 'Disable', 'legit-news-pro' )
        );
        return apply_filters( 'legit_news_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'legit_news_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function legit_news_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'legit-news-pro' ),
            'off'       => esc_html__( 'No', 'legit-news-pro' )
        );
        return apply_filters( 'legit_news_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'legit_news_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function legit_news_pro_sortable_sections() {
        $sections = array(
            'breaking_news'      => esc_html__( 'Breaking News', 'legit-news-pro' ),
            'hero_post'          => esc_html__( 'Hero Post', 'legit-news-pro' ),
            'must_read'          => esc_html__( 'Must Read', 'legit-news-pro' ),
            'main_post'          => esc_html__( 'Main Post', 'legit-news-pro' ),
            'related_post'       => esc_html__( 'Related Post', 'legit-news-pro' ),
        );
        return apply_filters( 'legit_news_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'legit_news_pro_weather_country_list' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function legit_news_pro_weather_country_list() {
        $response = wp_remote_get( 'https://restcountries.eu/rest/v2/all' );
        try {
            $json = json_decode( $response['body'] );
     
        } catch ( Exception $ex ) {
            $json = null;
        } 
        $sections = array(
            $json->alpha2Code      => $json->name,
        );

        return apply_filters( 'legit_news_pro_weather_country_list', $sections );
    }
endif;