<?php
/**
 * Blog section
 *
 * This is the template for the content of Blog section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_blog_section' ) ) :
    /**
    * Add Blog section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_blog_section() {
        $options = legit_news_pro_get_theme_options();
        
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'legit_news_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get Blog section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_blog_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Defualt blog section now.
        legit_news_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_blog_section_details' ) ) :
    /**
    * Blog section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input Blog section details.
    */
    function legit_news_pro_get_blog_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        $blog_content_type  = $options['blog_content_type']; // Content type.
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3; // Blog Count.
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       =  legit_news_pro_trim_content( 30 );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Blog section content details.
add_filter( 'legit_news_pro_filter_blog_section_details', 'legit_news_pro_get_blog_section_details' );


if ( ! function_exists( 'legit_news_pro_render_blog_section' ) ) :
  /**
   * Start Blog section
   *
   * @return string Blog content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_blog_section( $content_details = array() ) {
        $options            = legit_news_pro_get_theme_options();
        $blog_btn_title     = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Read All Articles', 'legit-news-pro' );
        $blog_title         = ! empty( $options['blog_title'] ) ? $options['blog_title'] : esc_html__( 'Read Our Travel Blog', 'legit-news-pro' );
        $blog_description   = ! empty( $options['blog_description'] ) ? $options['blog_description'] : '';


        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="business-latest-posts" class="relative page-section">
                <div class="wrapper">
                    <div class="business-section-header">
                        <h2 class="business-section-title"><?php echo esc_html($blog_title); ?></h2>
                        <p class="business-section-subtitle"><?php echo wp_kses_post($blog_description); ?></p>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content clear col-3">
                    <?php foreach($content_details as $content): ?>

                        <article class="has-post-thumbnail">
                            <div class="business-post-item">
                                <div class="featured-image">
                                    <a href="#"><img src="<?php echo $content['image']; ?>" alt="<?php echo esc_html($content['title']); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo $content['url']; ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="entry-meta clear">
                                        <?php legit_news_pro_posted_on($content['id']); 
                                        
                                        if(!empty($blog_btn_title)): ?>
                                            <span class="more-link"><a href="<?php echo $content['url']; ?>"><?php echo esc_html($blog_btn_title); ?></a></span>
                                        <?php endif; ?>

                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .business-post-item -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-latest-posts -->

    <?php }
endif;

