<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_service_section() {
        $options = legit_news_pro_get_theme_options();

        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'legit_news_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
 
        // Render Default service section now.
        legit_news_pro_render_service_section( $section_details );

    }
endif;

if ( ! function_exists( 'legit_news_pro_get_service_section_details' ) ) :
    /**
    * Service section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input service section details.
    */
    function legit_news_pro_get_service_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

       
        $service_content_type  = $options['service_content_type'];  // Content type.
        $service_count  = ! empty( $options['service_count'] ) ? $options['service_count'] : 3; // Service Post Count
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $service_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif
;
// service section content details.
add_filter( 'legit_news_pro_filter_service_section_details', 'legit_news_pro_get_service_section_details' );


if ( ! function_exists( 'legit_news_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_service_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $service_title          = isset($options['service_title']) ? $options['service_title'] : esc_html__('Make Successful Business','legit-news-pro');
        $service_description    = isset( $options['service_description']) ? $options['service_description'] : '';


        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="business-services" class="relative page-section">
            <div class="wrapper">
                <div class="business-section-header">
                    <h2 class="business-section-title"><?php echo esc_html($service_title); ?></h2>
                    <p class="business-section-subtitle"><?php echo esc_html($service_description); ?></p>
                </div><!-- .business-section-header -->

                <div class="business-section-content clear col-3">
                <?php foreach ($content_details as $i=>$content) : ?>

                    <article>
                        <div class="business-service-item">

                            <div class="business-service-icon">
                                <a href="<?php echo esc_url($content['url']); ?>"><i class="fa <?php echo $options['service_content_icon_' . ($i+1) . '']; ?>"></i></a>
                            </div><!-- .business-service-icon -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title'])?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .business-service-item -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .business-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #business-services -->

    <?php }
endif;
