<?php
/**
 * Culture  section
 *
 * This is the template for the content of culture section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_culture_section' ) ) :
    /**
    * Add culture section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_culture_section() {
        $options = legit_news_pro_get_theme_options();
        // Check if culture is enabled on frontpage
        $culture_enable = apply_filters( 'legit_news_pro_section_status', true, 'culture_section_enable' );

        if ( true !== $culture_enable ) {
            return false;
        }
        // Get culture section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_culture_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render culture section now.
        legit_news_pro_render_culture_section( $section_details );
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_culture_section_details' ) ) :
    /**
    * culture section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input culture section details.
    */
    function legit_news_pro_get_culture_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        // Content type.
        $culture_content_type  = $options['culture_content_type'];
        $culture_count = ! empty( $options['culture_count'] ) ? $options['culture_count'] :4;
        
        $content = array();
        switch ( $culture_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $culture_count; $i++ ) {
                    if ( ! empty( $options['culture_content_page_' . $i] ) )
                        $page_ids[] = $options['culture_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $culture_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $culture_count; $i++ ) {
                    if ( ! empty( $options['culture_content_post_' . $i] ) )
                        $post_ids[] = $options['culture_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $culture_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['culture_content_category'] ) ? $options['culture_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $culture_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() .'/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// culture section content details.
add_filter( 'legit_news_pro_filter_culture_section_details', 'legit_news_pro_get_culture_section_details' );


if ( ! function_exists( 'legit_news_pro_render_culture_section' ) ) :
  /**
   * Start culture section
   *
   * @return string culture content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_culture_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $home_layout = $options['home_layout'];

        if ( empty( $content_details ) ) {
            return;
        } 
        $content = array_chunk($content_details, 4);
        ?>
           <div id="culture">
                <div class="section-header">
                <h2 class="section-title"><?php echo esc_html($options['culture_title']); ?></h2>
            </div><!-- .section-header -->

            <?php foreach($content as $key=>$posts): 
            $first_post = array_shift($posts);
                ?>

            <div class="<?php echo (($key+1)%2==1) ? 'culture' : 'tradition'; ?>-wrapper">
                <div class="<?php echo (($key+1)%2==1) ? 'culture' : 'tradition'; ?>-section-wrapper clear">
                    <div class="hentry">
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($first_post['image']); ?>');">
                                <div class="overlay"></div>
                            </div>

                            <?php if($home_layout != 'second-design') echo '<div class="entry-container">'; ?>

                                <div class="entry-meta">
                                    <span class="cat-links">
                                            <?php the_category( '', '', $first_post['id'] ); ?>
                                    </span><!-- .cat-links -->      
                                </div><!-- .entry-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $first_post['url'] ); ?>"><?php echo esc_html($first_post['title']); ?></a></h2>
                                </header><!-- .entry-header -->

                                <div class="footer-meta">
                                <?php 
                                    legit_news_pro_posted_on( $first_post['id'] );
                                    echo legit_news_pro_author($first_post['id']); ?>
                                </div><!-- .footer-meta -->

                            <?php if($home_layout != 'second-design') echo '</div>'; ?>

                        </article>
                    </div><!-- .hentry -->

                    <div class="hentry">
                        <?php foreach($posts as $post): ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                <div class="overlay"></div>

                            <?php if($home_layout != 'second-design') echo '</div><div class="entry-container">'; ?>
                            
                                <div class="entry-meta">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $post['id'] ); ?>
                                    </span><!-- .cat-links -->      
                                </div><!-- .entry-meta -->

                            <?php if($home_layout == 'second-design') echo '</div><div class="entry-container">'; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                </header><!-- .entry-header -->

                                <div class="footer-meta">
                                <?php 
                                    legit_news_pro_posted_on( $post['id'] );
                                    echo legit_news_pro_author($post['id']); ?>
                                </div><!-- .footer-meta -->
                            </div><!-- .entry-container -->
                        </article>
                        <?php endforeach;?>
                    </div><!-- .hentry -->
                </div><!-- .culture-section-wrapper -->
            </div><!-- .culture-wrapper -->
            <?php endforeach; ?>
        </div><!-- #culture -->
    <?php }
endif;
