<?php
/**
 * Hero Post section
 *
 * This is the template for the content of Hero Post section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_hero_post_section' ) ) :
    /**
    * Add Hero Post section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_hero_post_section() {
        $options = legit_news_pro_get_theme_options();
        // Check if Hero Post is enabled on frontpage
        $hero_post_enable = apply_filters( 'legit_news_pro_section_status', true, 'hero_post_section_enable' );

        if ( true !== $hero_post_enable ) {
            return false;
        }
        // Get Hero Post section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_hero_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        
        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render Hero Post section now.
                legit_news_pro_render_hero_post_section( $section_details );
                break;
            
            case 'second-design':
                // Render About business section .
                legit_news_pro_render_second_hero_post_section( $section_details );
                break;
            
            default:
                // Render About default design section .
                legit_news_pro_render_hero_post_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'legit_news_pro_get_hero_post_section_details' ) ) :
    /**
    * Hero Post section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input Hero Post section details.
    */
    function legit_news_pro_get_hero_post_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        $hero_post_content_type  = $options['hero_post_content_type']; // Content type.
        $hero_post_count = ! empty( $options['hero_post_count'] ) ? $options['hero_post_count'] : 3; // post count
        
        $content = array();
        switch ( $hero_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $hero_post_count; $i++ ) {
                    if ( ! empty( $options['hero_post_content_page_' . $i] ) )
                        $page_ids[] = $options['hero_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $hero_post_count ),
                    'orderby'           => 'post__in',
                    );                    
                break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $hero_post_count; $i++ ) {
                    if ( ! empty( $options['hero_post_content_post_' . $i] ) )
                        $post_ids[] = $options['hero_post_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $hero_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            case 'category':
                $cat_id = ! empty( $options['hero_post_content_category'] ) ? $options['hero_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $hero_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            default:
                break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : $i = 1;
            $content['left_post'] = array();
            $content['mid_post'] = array();
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = legit_news_pro_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() .'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                if($i % 3 == 1 || $i % 3 == 0){
                    array_push( $content['left_post'], $page_post );
                }else{
                    array_push( $content['mid_post'], $page_post );
                }
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Hero Post section content details.
add_filter( 'legit_news_pro_filter_hero_post_section_details', 'legit_news_pro_get_hero_post_section_details' );


if ( ! function_exists( 'legit_news_pro_render_hero_post_section' ) ) :
  /**
   * Start Hero Post section
   *
   * @return string Hero Post content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_hero_post_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $btn_label = $options['hero_post_btn_title'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="hero-posts">
            <div class="wrapper">
                <div class="hero-wrapper col-2">
                    <div class="hentry">
                        <div class="left-posts">
                            <?php foreach($content_details['left_post'] as $post): ?>
                            <article>
                                <div class="image-wrapper clear">
                                    <div class="featured-wrapper">
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                            <a href="<?php echo esc_url( $post['url'] ); ?>" class="post-thumbnail-link"></a>
                                            <div class="entry-meta">
                                                <span class="cat-links">
                                                    <?php the_category( '', '', $post['id'] ); ?>
                                                </span><!-- .cat-links -->      
                                            </div>
                                        </div>
                                    </div>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                        
                                        <?php legit_news_pro_posted_on( $post['id'] ); ?>
                                    </header>
                                </div>

                                <div class="entry-container">
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($post['excerpt']); ?></p>
                                    </div>

                                    <div class="view-all">
                                        <a href="<?php echo esc_url( $post['url'] ); ?>" class="more-link"><?php echo esc_html($btn_label);
                                        echo legit_news_pro_get_svg( array( 'icon' => 'arrow-right' ) );?>
                                        </a>
                                    </div>
                                </div>
                            </article>

                            <?php endforeach ;?>

                        </div><!-- .left-post -->

                        <div class="mid-posts">
                        <?php foreach($content_details['mid_post'] as $post): ?>
                            <article>
                                <div class="mid-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                        <a href="<?php echo esc_url( $post['url'] ); ?>" class="post-thumbnail-link"></a>
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $post['id'] ); ?>
                                            </span><!-- .cat-links -->      
                                        </div>
                                    </div>

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post($post['excerpt']); ?></p>
                                        </div>

                                        <?php if(!empty($btn_label)): ?>
                                            <div class="view-all">
                                                <a href="<?php echo esc_url( $post['url'] ); ?>" class="more-link"><?php echo esc_html($btn_label);
                                                echo legit_news_pro_get_svg( array( 'icon' => 'arrow-right' ) );?>
                                                </a>
                                            </div><!-- .view-all -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .mid-wrapper -->
                            </article>
                            <?php endforeach ;?>
                        </div><!-- .mid-post -->
                    </div><!-- .hentry -->

            <?php if( is_active_sidebar('hero-post-sidebar') ) : ?>
                    <div class="hentry">
                        <div class="right-post">
                            <?php dynamic_sidebar('hero-post-sidebar');?>
                        </div><!-- .right -post -->
                    </div><!-- .hentry -->
            <?php endif; ?>
                </div><!-- .hero-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #hero-posts -->   
    <?php }
endif;


if ( ! function_exists( 'legit_news_pro_render_second_hero_post_section' ) ) :
  /**
   * Start Hero Post section
   *
   * @return string Hero Post content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_second_hero_post_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $btn_label = $options['hero_post_btn_title'];

        if ( empty( $content_details ) ) {
            return;
        } 
        $content = array_merge($content_details['left_post'],$content_details['mid_post']); ?>

        <div id="featured-posts">
            <div class="wrapper">
                <div class="grid">
                <?php foreach($content as $post): ?>
                    <article class="grid-item">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                            <div class="overlay"></div>
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php the_category( '', '', $post['id'] ); ?>
                                </span><!-- .cat-links -->      
                            </div>

                            <div class="entry-container">

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                </header>

                                <div class="footer-meta">
                                <?php 
                                    legit_news_pro_posted_on( $post['id'] );
                                    echo legit_news_pro_author($post['id']); ?> 

                                </div><!-- .footer-meta -->
                            </div><!-- .entry- container -->
                        </div><!-- .featured-image -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .grid -->
            </div><!-- .wrapper -->
        </div><!-- #featured-posts --> 
    <?php }
endif;
