<?php
/**
 * Single Column  section
 *
 * This is the template for the content of single_column section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_single_column_section' ) ) :
    /**
    * Add single_column section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_single_column_section() {
        $options = legit_news_pro_get_theme_options();
        // Check if single_column is enabled on frontpage
        $single_column_enable = apply_filters( 'legit_news_pro_section_status', true, 'single_column_section_enable' );

        if ( true !== $single_column_enable ) {
            return false;
        }
        // Get single_column section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_single_column_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render single_column section now.
        legit_news_pro_render_single_column_section( $section_details );
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_single_column_section_details' ) ) :
    /**
    * single_column section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input single_column section details.
    */
    function legit_news_pro_get_single_column_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        // Content type.
        $single_column_content_type  = $options['single_column_content_type'];
        $single_column_count = ! empty( $options['single_column_count'] ) ? $options['single_column_count'] : 5;
        
        $content = array();
        switch ( $single_column_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $single_column_count; $i++ ) {
                    if ( ! empty( $options['single_column_content_page_' . $i] ) )
                        $page_ids[] = $options['single_column_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $single_column_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $single_column_count; $i++ ) {
                    if ( ! empty( $options['single_column_content_post_' . $i] ) )
                        $post_ids[] = $options['single_column_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $single_column_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['single_column_content_category'] ) ? $options['single_column_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $single_column_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() .'/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// single_column section content details.
add_filter( 'legit_news_pro_filter_single_column_section_details', 'legit_news_pro_get_single_column_section_details' );


if ( ! function_exists( 'legit_news_pro_render_single_column_section' ) ) :
  /**
   * Start single_column section
   *
   * @return string single_column content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_single_column_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="single-column-news" class="grid-layout">
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html($options['single_column_title']); ?></h2>
            </div><!-- .section-header -->

            <div class="section-content col-2 clear">
                <?php foreach($content_details as $post): ?>

                <article class="has-post-thumbnail">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                        <a href="<?php echo esc_url($post['url']); ?>" class="post-thumbnail-link"></a>

                        <div class="entry-meta">
                            <span class="cat-links">
                                <?php the_category( '', '', $post['id'] ); ?>
                            </span><!-- .cat-links -->
                        </div><!-- .entry-meta -->

                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <div class="footer-meta">
                        <?php 
                            legit_news_pro_posted_on( $post['id'] );
                            echo legit_news_pro_author($post['id']); ?>
                        </div><!-- .footer-meta -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                        </header><!-- .entry-header -->
                        
                        <div class="entry-content">
                            <p><?php echo wp_kses_post($post['excerpt']); ?></p>
                        </div><!-- .entry-content -->
                    </div><!-- .entry-container -->
                </article>

                <?php endforeach; ?>
            </div><!-- .section-content -->
        </div><!-- #single-column-news -->
    <?php }
endif;
